@@ -188,8 +188,8 @@ def findglobaltags(ui, repo):
         return alltags
 
     for head in reversed(heads):  # oldest to newest
-        assert head in repo.changelog.nodemap, \
-               "tag cache returned bogus head %s" % short(head)
+        assert head in repo.changelog.nodemap, (
+               "tag cache returned bogus head %s" % short(head))
     fnodes = _filterfnodes(tagfnode, reversed(heads))
     alltags = _tagsfromfnodes(ui, repo, fnodes)
 
@@ -536,7 +536,7 @@ def tag(repo, names, node, message, local, user, date, editor=False):
     date: date tuple to use if committing'''
 
     if not local:
-        m = matchmod.exact(repo.root, '', ['.hgtags'])
+        m = matchmod.exact(['.hgtags'])
         if any(repo.status(match=m, unknown=True, ignored=True)):
             raise error.Abort(_('working copy of .hgtags is changed'),
                              hint=_('please commit .hgtags manually'))
@@ -548,7 +548,7 @@ def tag(repo, names, node, message, local, user, date, editor=False):
 
 def _tag(repo, names, node, message, local, user, date, extra=None,
          editor=False):
-    if isinstance(names, str):
+    if isinstance(names, bytes):
         names = (names,)
 
     branches = repo.branchmap()
@@ -610,7 +610,7 @@ def _tag(repo, names, node, message, local, user, date, extra=None,
     if '.hgtags' not in repo.dirstate:
         repo[None].add(['.hgtags'])
 
-    m = matchmod.exact(repo.root, '', ['.hgtags'])
+    m = matchmod.exact(['.hgtags'])
     tagnode = repo.commit(message, user, date, extra=extra, match=m,
                           editor=editor)
 
